@@ -1,6 +1,6 @@
 library(withr)
 
-setup <- function(code) {
+setup <- function(code, deactivate=TRUE) {
   app_dir <- tempfile(pattern="app")
   renv_dir <- tempfile(pattern="renv")
   library_dir <- tempfile(pattern="library")
@@ -16,5 +16,13 @@ setup <- function(code) {
   Sys.setenv(RENV_PATHS_ROOT=renv_dir)
   Sys.setenv(RENV_PATHS_LIBRARY_ROOT=library_dir)
 
+  if (deactivate) {
+    on.exit(renv::deactivate())
+  }
+
   with_dir(app_dir, code)
 }
+
+removeVenv <- function() {
+  unlink(Sys.getenv("TEST_JETPACK_ROOT", "none"), recursive=TRUE)
+}
